<ACTOR.elaborating> Have you filled in your timesheet?
    1. Yes
    2. No
    3. Not sure

<ACTOR> Oh *really*? You `think` so? I _bet_!

<NARRATOR.elaborating> Maybe now's a good time to ask {ACTOR.name} a question.
    1. Ask about LAAR
    2. Ask about Thackaray
    3. Ask about Lewis

